@@ -75,7 +75,7 @@ class MultiCaseTimer:
             candidate_results: Dict[str, List[float]] = {}
             LOGGER.info("Evaluate candidate '%s' %dx%d times..", candidate_label, repeat, candidate_number)
             for data_label, test_data in self._data.items():
-                raw_timings = Timer(lambda: func(test_data)).repeat(repeat, candidate_number)  # noqa: B023
+                raw_timings = self._get_raw_timings(func, test_data, candidate_number, repeat)
                 best, worst = min(raw_timings), max(raw_timings)
                 candidate_results[data_label] = [dt / candidate_number for dt in raw_timings]
                 if worst >= best * 4:  # pragma: no cover
@@ -90,6 +90,11 @@ class MultiCaseTimer:
 
         return run_results
 
+    @staticmethod
+    def _get_raw_timings(func: CandFunc, test_data: DataType, repeat: int, number: int) -> List[float]:
+        """Exists so that it can be overridden for testing."""
+        return Timer(lambda: func(test_data)).repeat(repeat, number)  # pragma: no cover
+
     def _compute_number_of_iterations(
         self, number: Optional[int], repeat: int, time_allocation: float
     ) -> Dict[str, int]:  # pragma: no cover
@@ -118,9 +123,13 @@ def _process_candidates(
     if callable(candidates):
         return {tname(candidates): candidates}
 
-    ans = {tname(c): c for c in candidates}
+    def make_label(a: Any) -> str:
+        name = tname(a)
+        return name[len("candidate_") :] if name.startswith("candidate_") else name
+
+    ans = {make_label(c): c for c in candidates}
     if len(ans) != len(candidates):
-        raise ValueError(f"Derived names for input {candidates=} is not unique. Use a dict to assign candidate names.")
+        raise ValueError(f"Derived names for input {candidates=} are not unique. Use a dict to assign candidate names.")
     return ans
 
 
